@@ -89,6 +89,7 @@ class Add(Expr, AssocOp):
         sympy.core.mul.Mul.flatten
 
         """
+        from sympy.calculus.util import AccumBounds
         rv = None
         if len(seq) == 2:
             a, b = seq
@@ -136,6 +137,10 @@ class Add(Expr, AssocOp):
                         return [S.NaN], [], None
                 continue
 
+            elif isinstance(o, AccumBounds):
+                coeff = o.__add__(coeff)
+                continue
+
             elif o is S.ComplexInfinity:
                 if coeff.is_finite is False:
                     # we know for sure the result will be nan
