@@ -186,6 +186,13 @@ class StrPrinter(Printer):
         return "%s%s, %s%s" % \
                (left, self._print(i.start), self._print(i.end), right)
 
+    def _print_AccumulationBounds(self, i):
+        left = '<'
+        right = '>'
+
+        return "%s%s, %s%s" % \
+                (left, self._print(i.min), self._print(i.max), right)
+
     def _print_Inverse(self, I):
         return "%s^-1" % self.parenthesize(I.arg, PRECEDENCE["Pow"])
 
@@ -321,30 +328,21 @@ class StrPrinter(Printer):
             return 'O(%s)' % self.stringify(expr.args, ', ', 0)
 
     def _print_Cycle(self, expr):
-        """We want it to print as Cycle in doctests for which a repr is required.
-
-        With __repr__ defined in Cycle, interactive output gives Cycle form but
-        during doctests, the dict's __repr__ form is used. Defining this _print
-        function solves that problem.
-
-        >>> from sympy.combinatorics import Cycle
-        >>> Cycle(1, 2) # will print as a dict without this method
-        Cycle(1, 2)
-        """
-        return expr.__repr__()
+        return expr.__str__()
 
     def _print_Permutation(self, expr):
         from sympy.combinatorics.permutations import Permutation, Cycle
         if Permutation.print_cyclic:
             if not expr.size:
-                return 'Permutation()'
+                return '()'
             # before taking Cycle notation, see if the last element is
             # a singleton and move it to the head of the string
             s = Cycle(expr)(expr.size - 1).__repr__()[len('Cycle'):]
             last = s.rfind('(')
             if not last == 0 and ',' not in s[last:]:
                 s = s[last:] + s[:last]
-            return 'Permutation%s' % s
+            s = s.replace(',', '')
+            return s
         else:
             s = expr.support()
             if not s:
@@ -501,6 +499,12 @@ class StrPrinter(Printer):
         return '%s**%s' % (self.parenthesize(expr.base, PREC),
                          self.parenthesize(expr.exp, PREC))
 
+    def _print_ImmutableDenseNDimArray(self, expr):
+        return str(expr)
+
+    def _print_ImmutableSparseNDimArray(self, expr):
+        return str(expr)
+
     def _print_Integer(self, expr):
         return str(expr.p)
 
