@@ -387,7 +387,8 @@ class ProductDomain(RandomDomain):
         for domain in self.domains:
             # Collect the parts of this event which associate to this domain
             elem = frozenset([item for item in other
-                              if domain.symbols.contains(item[0]) == S.true])
+                              if sympify(domain.symbols.contains(item[0]))
+                              is S.true])
             # Test this sub-event
             if elem not in domain:
                 return False
@@ -746,7 +747,7 @@ def cdf(expr, condition=None, evaluate=True, **kwargs):
     {9: 1/4, 12: 1/2, 15: 3/4, 18: 1}
 
     >>> cdf(X)
-    Lambda(_z, erf(sqrt(2)*_z/2)/2 + 1/2)
+    Lambda(_z, -erfc(sqrt(2)*_z/2)/2 + 1)
     """
     if condition is not None:  # If there is a condition
         # Recompute on new conditional expr
